# STAGPy - Spectral Toolkit of Algorithms for Graphs

[![Test](https://github.com/staglibrary/stagpy/actions/workflows/github-actions-test.yml/badge.svg?branch=main)](https://github.com/staglibrary/stagpy/actions/workflows/github-actions-test.yml)
[![Python package build](https://github.com/staglibrary/stagpy/actions/workflows/github-actions-release.yml/badge.svg)](https://github.com/staglibrary/stagpy/actions/workflows/github-actions-release.yml)

STAG is a library providing efficient spectral algorithms for the analysis of massive graphs. STAGPy is a python wrapper around the underlying C++ library which provides convenient methods for learning on graphs in python.

## Project Status
The STAG library is under active development. Further documentation will be added here in the near future.
